summaryrefslogtreecommitdiffstats
path: root/libdimension
diff options
context:
space:
mode:
authorTavian Barnes <tavianator@gmail.com>2010-01-17 14:38:28 -0500
committerTavian Barnes <tavianator@gmail.com>2010-01-17 14:38:28 -0500
commit517860ffe8301ea9c7b6544f2f482468b3414f98 (patch)
tree6b5884309add3df2ab5829b1817fdaf60f4ddb99 /libdimension
parenta868a2958dd7ea138b02543ef81cc78abf8622c7 (diff)
downloaddimension-517860ffe8301ea9c7b6544f2f482468b3414f98.tar.xz
Missed some kD splay tree references.
Diffstat (limited to 'libdimension')
-rw-r--r--libdimension/bvst.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/libdimension/bvst.c b/libdimension/bvst.c
index a73b4b2..ddb3c41 100644
--- a/libdimension/bvst.c
+++ b/libdimension/bvst.c
@@ -32,12 +32,12 @@ dmnsn_new_bvst()
if (tree) {
tree->root = NULL;
} else {
- dmnsn_error(DMNSN_SEVERITY_HIGH, "kD splay tree allocation failed.");
+ dmnsn_error(DMNSN_SEVERITY_HIGH, "BVST allocation failed.");
}
return tree;
}
/* Recursively copy the nodes of a kD splay tree */
static dmnsn_bvst_node *
dmnsn_bvst_copy_recursive(dmnsn_bvst_node *root)
{
@@ -54,7 +54,7 @@ dmnsn_bvst_copy_recursive(dmnsn_bvst_node *root)
return node;
}
-/* Copy a kD splay tree */
+/* Copy a BVST */
dmnsn_bvst *
dmnsn_bvst_copy(dmnsn_bvst *tree)
{
@@ -66,7 +66,7 @@ dmnsn_bvst_copy(dmnsn_bvst *tree)
return copy;
}
/* Recursively free a kD splay tree */
void
dmnsn_delete_bvst_recursive(dmnsn_bvst_node *node)
{
@@ -77,7 +77,7 @@ dmnsn_delete_bvst_recursive(dmnsn_bvst_node *node)
}
}
-/* Free a kD splay tree */
+/* Free a BVST */
void
dmnsn_delete_bvst(dmnsn_bvst *tree)
{
@@ -450,7 +450,7 @@ dmnsn_new_bvst_node()
{
dmnsn_bvst_node *node = malloc(sizeof(dmnsn_bvst_node));
if (!node) {
- dmnsn_error(DMNSN_SEVERITY_HIGH, "kD splay tree node allocation failed.");
+ dmnsn_error(DMNSN_SEVERITY_HIGH, "BVST node allocation failed.");
}
return node;
}
@@ -32,12 +32,12 @@ dmnsn_new_bvst()
return tree;
}
-/* Recursively copy the nodes of a kD splay tree */
+/* Recursively copy the nodes of a BVST */
static dmnsn_bvst_node *
dmnsn_bvst_copy_recursive(dmnsn_bvst_node *root)
@@ -66,7 +66,7 @@ dmnsn_bvst_copy(dmnsn_bvst *tree)
return copy;
}
-/* Recursively free a kD splay tree */
+/* Recursively free a BVST */
void
dmnsn_delete_bvst_recursive(dmnsn_bvst_node *node)